#
# spec file for package kitinerary
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           kitinerary
Version:        18.12.3
Release:        lp151.2.4.1
Summary:        Data model and extraction system for travel reservations
License:        LGPL-2.1-or-later
Group:          System/GUI/KDE
URL:            http://www.kde.org
Source0:        http://download.kde.org/stable/applications/%{version}/src/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules >= 1.0.0
BuildRequires:  kcalcore-devel
BuildRequires:  kcontacts-devel
BuildRequires:  kf5-filesystem
BuildRequires:  kmime-devel
BuildRequires:  kpkpass-devel
# disabled as it causes kmail to crash with certain mails (boo#1165440)
#BuildRequires:  libpoppler-qt5-devel
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5Test)

%description
Kitinerary is a library which provides a data model and a system to extract information
from travel reservations. The model can then be reused in other applications.

%package -n libKPimItinerary5
Summary:        Data model and extraction system for travel reservations
Group:          System/Libraries
Recommends:     libKPimItinerary5-lang

%description -n libKPimItinerary5
Kitinerary is a library which provides a data model and a system to extract information
from travel reservations. The model can then be reused in other applications.
This package contains the library itself.

%package devel
Summary:        Development files for kitinerary
Group:          Development/Libraries/KDE
Requires:       libKPimItinerary5 = %{version}

%description devel
This package contains all necessary include files and libraries needed
to build programs that use the kitinerary library.

%lang_package -n libKPimItinerary5

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
  %if %{with lang}
    %find_lang %{name} --with-man --with-qt --all-name
  %endif

%post -n libKPimItinerary5 -p /sbin/ldconfig
%postun -n libKPimItinerary5 -p /sbin/ldconfig

%files -n libKPimItinerary5
%license COPYING.LIB
%{_kf5_libdir}/libKPimItinerary.so.*
%{_kf5_debugdir}/*.categories

%files devel
%dir %{_includedir}/KPim/
%{_includedir}/KPim/KItinerary/
%{_includedir}/KPim/kitinerary/
%{_kf5_cmakedir}/KPimItinerary/
%{_kf5_libdir}/libKPimItinerary.so

%if %{with lang}
%files -n libKPimItinerary5-lang -f %{name}.lang
%endif

%changelog
* Thu Apr  9 2020 wbauer@tmo.at
- Build without poppler (i.e. PDF support) to avoid kmail crashing
  on certain emails due to a conflict between libopenjpeg1 (loaded
  by QtWebEngine via ffmpeg/libavcodec) and libopenjp2 (used by
  poppler) (boo#1165440)
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * Add missing comparison operators
  * Fix compatibility with Poppler 0.72
  * Fix FCM extractor for single digit flight numbers
  * Remove obsolete todo
  * Improve airport lookup by considering alternative umlaut transliterations
  * Cleanup airport name lookup code a bit
  * Fix flight calendar entries when IATA airport code is missing
  * Add arrival terminal property
  * Add Easyjet extractor
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * GBool -> bool
  * Relax leading space offset detection for international tickets
  * Auto-detect leading space in compact/international DB tickets
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Fri Sep  7 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Run the generic IATA BCBP extractor also for Vueling
  * Make the pdfdocumenttest pass without Poppler
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Fix binary Aztec barcode encoding for ticket tokens
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * None
* Thu Apr 12 2018 lbeltrame@kde.org
- Initial package
